import { styled } from '@mui/material/styles';
import Menu from '@mui/material/Menu';
import MenuItem from '@mui/material/MenuItem';
import NotificationsNoneIcon from '@mui/icons-material/NotificationsNone';
import VolumeOffIcon from '@mui/icons-material/VolumeOff';
import DeleteOutlineIcon from '@mui/icons-material/DeleteOutline';
import { useDispatch } from 'react-redux';
import { muteChat,removeChatForBoth } from '../../../../../api-data';
import { actionIsOpen } from '../../../../../redux/control/action';

const StyledMenu = styled((props:any) => (
  <Menu
    elevation={0}
    {...props}
  />
))(({ theme }:any) => ({
  '& .MuiPaper-root': {
    borderRadius: 10,
    marginTop: theme.spacing(-2),
    minWidth: 220,
    color:
      theme.palette.mode === 'light' ? 'rgb(55, 65, 81)' : theme.palette.grey[500],
    boxShadow:
      'rgb(255, 255, 255) 0px 0px 0px 0px, rgba(0, 0, 0, 0.05) 0px 0px 0px 1px, rgba(0, 0, 0, 0.1) 0px 10px 15px -3px, rgba(0, 0, 0, 0.05) 0px 4px 6px -2px',
    '& .MuiMenu-list': {
      padding: '14px 14px',
    },
    '& .MuiMenuItem-root': {
      marginBottom: theme.spacing(1),
      '& .MuiSvgIcon-root': {
        fontSize: 21,
        color: theme.palette.text.secondary,
        marginRight: theme.spacing(4),
      }
    },
  },
}));

interface IContextMenuBar {
  setModal: any,
  mute: boolean,
  companionId:string,
}
const ContextMenuBar = ({ setModal, mute, companionId }: IContextMenuBar) => {
  const dispatch = useDispatch()
  const handleClose = (i: number | undefined): void => {
    if (i === 0) muteChat(companionId)
    if (i === 1) {
      removeChatForBoth(companionId)
      dispatch(actionIsOpen(''))
    }
    setModal(false)
  }
  return (
      <StyledMenu
        id="demo-positioned-menu"
        aria-labelledby="demo-positioned-button"
        open={true}
        onClose={handleClose}
      >
        <MenuItem onClick={() => handleClose(0)}>
          {mute ? <NotificationsNoneIcon /> : <VolumeOffIcon />}
          {mute ? 'Unmute chat':'Mute chat'}
        </MenuItem>
        <MenuItem style={{color:'#f02a2a'}} onClick={() => handleClose(1)}>
            <DeleteOutlineIcon style={{color:'#f02a2a'}}/>
            Delete chat
         </MenuItem>        
       </StyledMenu>    
  );
}
export default ContextMenuBar